"""
Py-Hub: A modular Python-based launcher hub
"""

__version__ = "1.0.0"
__author__ = "Unk0wn_4uth0r"
__description__ = "A modular Python-based launcher hub for managing files, scripts, and tools."

from .main import main

__all__ = ["main"]
