# simple terminal snake placeholder (non-pygame)
import time
print("This is a simple placeholder for Snake.")
print("In a full version you would use pygame for graphics.")
time.sleep(1)
print("Pretend the snake moved and ate an apple. Score: 10")
input("Press ENTER to exit...")

